@@ -12,9 +12,13 @@ from __future__ import print_function
 from __future__ import unicode_literals
 
 import re
+import typing
 
 from .errors import IllegalBackReference
 
+if False:  # typing.TYPE_CHECKING
+    from typing import List, Text, Tuple
+
 
 __all__ = [
     "abspath",
@@ -47,6 +51,7 @@ _requires_normalization = re.compile(
 
 
 def normpath(path):
+    # type: (Text) -> Text
     """Normalize a path.
 
     This function simplifies a path by collapsing back-references
@@ -75,7 +80,7 @@ def normpath(path):
         return path.rstrip('/')
 
     prefix = '/' if path.startswith('/') else ''
-    components = []
+    components = []  # type: List[Text]
     try:
         for component in path.split('/'):
             if component in '..':  # True for '..', '.', and ''
@@ -91,6 +96,7 @@ def normpath(path):
 
 
 def iteratepath(path):
+    # type: (Text) -> List[Text]
     """Iterate over the individual components of a path.
 
     Arguments:
@@ -111,11 +117,12 @@ def iteratepath(path):
 
 
 def recursepath(path, reverse=False):
+    # type: (Text, bool) -> List[Text]
     """Get intermediate paths from the root to the given path.
 
     Arguments:
         path (str): A PyFilesystem path
-        reverse (bool, optional): Reverses the order of the paths
+        reverse (bool): Reverses the order of the paths
             (default `False`).
 
     Returns:
@@ -148,6 +155,7 @@ def recursepath(path, reverse=False):
 
 
 def isabs(path):
+    # type: (Text) -> bool
     """Check if a path is an absolute path.
 
     Arguments:
@@ -162,6 +170,7 @@ def isabs(path):
 
 
 def abspath(path):
+    # type: (Text) -> Text
     """Convert the given path to an absolute path.
 
     Since FS objects have no concept of a *current directory*, this
@@ -181,6 +190,7 @@ def abspath(path):
 
 
 def relpath(path):
+    # type: (Text) -> Text
     """Convert the given path to a relative path.
 
     This is the inverse of `abspath`, stripping a leading ``'/'`` from
@@ -201,6 +211,7 @@ def relpath(path):
 
 
 def join(*paths):
+    # type: (*Text) -> Text
     """Join any number of paths together.
 
     Arguments:
@@ -219,7 +230,7 @@ def join(*paths):
 
     """
     absolute = False
-    relpaths = []
+    relpaths = []       # type: List[Text]
     for p in paths:
         if p:
             if p[0] == '/':
@@ -234,6 +245,7 @@ def join(*paths):
 
 
 def combine(path1, path2):
+    # type: (Text, Text) -> Text
     """Join two paths together.
 
     This is faster than :func:`~fs.path.join`, but only works when the
@@ -258,6 +270,7 @@ def combine(path1, path2):
 
 
 def parts(path):
+    # type: (Text) -> List[Text]
     """Split a path in to its component parts.
 
     Arguments:
@@ -281,6 +294,7 @@ def parts(path):
 
 
 def split(path):
+    # type: (Text) -> Tuple[Text, Text]
     """Split a path into (head, tail) pair.
 
     This function splits a path into a pair (head, tail) where 'tail' is
@@ -308,6 +322,7 @@ def split(path):
 
 
 def splitext(path):
+    # type: (Text) -> Tuple[Text, Text]
     """Split the extension from the path.
 
     Arguments:
@@ -321,9 +336,13 @@ def splitext(path):
         ('baz', '.txt')
         >>> splitext('foo/bar/baz.txt')
         ('foo/bar/baz', '.txt')
+        >>> splitext('foo/bar/.foo')
+        ('foo/bar/.foo', '')
 
     """
     parent_path, pathname = split(path)
+    if pathname.startswith('.') and pathname.count('.') == 1:
+        return path, ''
     if '.' not in pathname:
         return path, ''
     pathname, ext = pathname.rsplit('.', 1)
@@ -332,6 +351,7 @@ def splitext(path):
 
 
 def isdotfile(path):
+    # type: (Text) -> bool
     """Detect if a path references a dot file.
 
     Arguments:
@@ -353,6 +373,7 @@ def isdotfile(path):
 
 
 def dirname(path):
+    # type: (Text) -> Text
     """Return the parent directory of a path.
 
     This is always equivalent to the 'head' component of the value
@@ -377,6 +398,7 @@ def dirname(path):
 
 
 def basename(path):
+    # type: (Text) -> Text
     """Return the basename of the resource referenced by a path.
 
     This is always equivalent to the 'tail' component of the value
@@ -401,6 +423,7 @@ def basename(path):
 
 
 def issamedir(path1, path2):
+    # type: (Text, Text) -> bool
     """Check if two paths reference a resource in the same directory.
 
     Arguments:
@@ -421,6 +444,7 @@ def issamedir(path1, path2):
 
 
 def isbase(path1, path2):
+    # type: (Text, Text) -> bool
     """Check if ``path1`` is a base of ``path2``.
 
     Arguments:
@@ -437,10 +461,11 @@ def isbase(path1, path2):
     """
     _path1 = forcedir(abspath(path1))
     _path2 = forcedir(abspath(path2))
-    return _path1.startswith(_path2)
+    return _path2.startswith(_path1)  # longer one is child
 
 
 def isparent(path1, path2):
+    # type: (Text, Text) -> bool
     """Check if ``path1`` is a parent directory of ``path2``.
 
     Arguments:
@@ -474,6 +499,7 @@ def isparent(path1, path2):
 
 
 def forcedir(path):
+    # type: (Text) -> Text
     """Ensure the path ends with a trailing forward slash.
 
     Arguments:
@@ -497,6 +523,7 @@ def forcedir(path):
 
 
 def frombase(path1, path2):
+    # type: (Text, Text) -> Text
     """Get the final path of ``path2`` that isn't in ``path1``.
 
     Arguments:
@@ -517,6 +544,7 @@ def frombase(path1, path2):
 
 
 def relativefrom(base, path):
+    # type: (Text, Text) -> Text
     """Return a path relative from a given base path.
 
     Insert backrefs as appropriate to reach the path from the base.
@@ -532,22 +560,23 @@ def relativefrom(base, path):
     '../../baz/index.html'
 
     """
-    base = list(iteratepath(base))
-    path = list(iteratepath(path))
+    base_parts = list(iteratepath(base))
+    path_parts = list(iteratepath(path))
 
     common = 0
-    for component_a, component_b in zip(base, path):
+    for component_a, component_b in zip(base_parts, path_parts):
         if component_a != component_b:
             break
         common += 1
 
-    return '/'.join(['..'] * (len(base) - common) + path[common:])
+    return '/'.join(['..'] * (len(base_parts) - common) + path_parts[common:])
 
 
 _WILD_CHARS = frozenset('*?[]!{}')
 
 
 def iswildcard(path):
+    # type: (Text) -> bool
     """Check if a path ends with a wildcard.
 
     Arguments:
