@@ -1,4 +1,5 @@
-"""Time related tools."""
+"""Time related tools.
+"""
 
 from __future__ import print_function
 from __future__ import unicode_literals
@@ -14,10 +15,14 @@ GMT = timezone('GMT')
 
 
 def datetime_to_epoch(d):
-    """Convert datetime to epoch."""
+    # type: (datetime) -> int
+    """Convert datetime to epoch.
+    """
     return timegm(d.utctimetuple())
 
 
 def epoch_to_datetime(t):
-    """Convert epoch time to a UTC datetime."""
+    # type: (int) -> datetime
+    """Convert epoch time to a UTC datetime.
+    """
     return utclocalize(utcfromtimestamp(t)) if t is not None else None
